==> field_manager_python_client-4.6.37.tar.gz: field_manager_python_client-4.6.37/field_manager_python_client/api/shapes/delete_shape_files_projects_project_id_shapes_shape_id_files_delete.py <==
from http import HTTPStatus
from typing import Any, Optional, Union, cast
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    project_id: str,
    shape_id: UUID,
    *,
    body: list[UUID],
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/projects/{project_id}/shapes/{shape_id}/files",
    }

    _kwargs["json"] = []
    for body_item_data in body:
        body_item = str(body_item_data)
        _kwargs["json"].append(body_item)

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, HTTPValidationError]]:
    if response.status_code == 204:
        response_204 = cast(Any, None)
        return response_204
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Response[Union[Any, HTTPValidationError]]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        shape_id=shape_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Optional[Union[Any, HTTPValidationError]]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
    """

    return sync_detailed(
        project_id=project_id,
        shape_id=shape_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Response[Union[Any, HTTPValidationError]]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        shape_id=shape_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Optional[Union[Any, HTTPValidationError]]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            shape_id=shape_id,
            client=client,
            body=body,
        )
    ).parsed

==> field_manager_python_client-4.6.97.tar.gz: field_manager_python_client-4.6.97/field_manager_python_client/api/shapes/delete_shape_files_projects_project_id_shapes_shape_id_files_delete.py <==
from http import HTTPStatus
from typing import Any, cast
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    project_id: str,
    shape_id: UUID,
    *,
    body: list[UUID],
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/projects/{project_id}/shapes/{shape_id}/files",
    }

    _kwargs["json"] = []
    for body_item_data in body:
        body_item = str(body_item_data)
        _kwargs["json"].append(body_item)

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | HTTPValidationError | None:
    if response.status_code == 204:
        response_204 = cast(Any, None)
        return response_204

    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | HTTPValidationError]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Response[Any | HTTPValidationError]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | HTTPValidationError]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        shape_id=shape_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Any | HTTPValidationError | None:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | HTTPValidationError
    """

    return sync_detailed(
        project_id=project_id,
        shape_id=shape_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Response[Any | HTTPValidationError]:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | HTTPValidationError]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        shape_id=shape_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    shape_id: UUID,
    *,
    client: AuthenticatedClient,
    body: list[UUID],
) -> Any | HTTPValidationError | None:
    """Delete Shape Files

     Delete multiple files associated with a shape

    Args:
        project_id (str):
        shape_id (UUID):
        body (list[UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | HTTPValidationError
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            shape_id=shape_id,
            client=client,
            body=body,
        )
    ).parsed
